#include <iostream>
#include <iomanip>
#include <sstream>
#include <cstdio>
#include "Xmm.h"

int main()
{
	Filter f = Xmm::FILTER_NONE;
	assert(Xmm::toFilter(Xmm::toString(f)) == f);	

	for (unsigned i = 0; i < xmmPayLoad.instruments().size(); ++i) {
		Xmm::Instrument ins = xmmPayLoad.instruments()[i]->id();
		assert(Xmm::toInstrument(Xmm::toString(ins)) == ins);
		assert(Xmm::toInstrument(Xmm::toString(ins, true)) == ins);
	}

	for (unsigned i = 0; i < xmmPayLoad.instruments().size(); ++i) {
		XmmInstrument *ins = xmmPayLoad.instruments()[i];
		if (ins->id() == Xmm::ERM)
			continue;

		std::cout<<"\nModes of "<<Xmm::toString(ins->id())<<":\n";
		const std::vector<Mode> &modes = ins->modes();
		for (unsigned n=0; n<modes.size(); ++n) {
			std::stringstream s;
			s<<modes[n];
			printf("%-40s %2d\n", s.str().c_str(), ins->modeIndex(modes[n]));
		}
		std::cout<<"Default mode is: "<<Xmm::toString(ins->defaultMode())
				 <<std::endl;

		std::cout<<"\nScience data modes of "<<Xmm::toString(ins->id())<<":\n";
		const std::vector<DataMode> &dataModes = ins->scienceDataModes();
		for (unsigned n=0; n<dataModes.size(); ++n) {
			std::stringstream s;
			s<<dataModes[n];
			printf("%-40s %2d\n", s.str().c_str(), n);
		}

		std::cout<<"\nTime resolution: "<<ins->timeResolution()<<"s\n";
	}

	for (unsigned i = 0; i < xmmPayLoad.instruments().size(); ++i) {
		XmmInstrument *ins = xmmPayLoad.instruments()[i];
		if (ins->id() == Xmm::ERM)
			continue;

		std::cout<<"\nFilters of "<<Xmm::toString(ins->id())<<":\n";
		const std::vector<Filter> &filters = ins->filters();
		for (unsigned n=0; n<filters.size(); ++n) {
			std::stringstream s;
			s<<filters[n];
			printf("%-40s %2d\n", s.str().c_str(),
								  ins->filterIndex(filters[n]));
		}
		std::cout<<"Default filter is: "<<Xmm::toString(ins->defaultFilter())
				 <<std::endl;
	}

	std::cout<<"\nGround stations:\n";
	std::cout<<"name  ID longitude lattitude elevation\n";
	for (unsigned p=0; p <= XmmMission::LASTGS; ++p) {
		const XmmGroundStation &gs = XmmMission::groundStation(
				XmmMission::GroundStationPlaces(p));
		std::cout<<gs.earthObject().name()<<' '<<gs.id()<<' '
				<<gs.earthObject().longitude()*RAD_TO_DEG<<"deg "
				<<gs.earthObject().lattitude()*RAD_TO_DEG<<"deg "
				<<gs.earthObject().altitude()<<"m\n";
	}
	std::cout<<"GS with ID 41 is: "
			 <<XmmMission::groundStation(41).earthObject().name()<<std::endl;
}
